@@ -32,13 +32,16 @@ class NicePrompt:
         selected = 0
 
         # Print out all the options, selected option has an arrow
+
         for c, i in enumerate(options.keys()):
             if c == selected:
-                print(f"{_.lightgreen} 🭬 {_.normal}{i}")
+                filler = " " * (_.width - (len(i) + 5))
+                print(f"{_.lightgreen} 🭬 {_.normal}{i}{filler}")
             else:
-                print(f" ◦ {i}")
+                filler = " " * (_.width - (len(i) + 5))
+                print(f" ◦ {i}{filler}")
 
-        with _.cbreak():
+        with _.cbreak(), _.hidden_cursor():
             while True:
                 val = _.inkey()
                 if (
@@ -65,9 +68,11 @@ class NicePrompt:
                 # Print out all the options, selected option has an arrow
                 for c, i in enumerate(options.keys()):
                     if c == selected:
-                        print(f"{_.lightgreen} 🭬 {_.normal}{i}")
+                        filler = " " * (_.width - (len(i) + 5))
+                        print(f"{_.lightgreen} 🭬 {_.normal}{i}{filler}")
                     else:
-                        print(f" ◦ {i}")
+                        filler = " " * (_.width - (len(i) + 5))
+                        print(f" ◦ {i}{filler}")
 
         for i in range(len(options) + 1):  # Clear the options list to tidy up terminal
             print(f"{_.move_up}{_.clear_eol}{_.move_up}")
@@ -120,18 +125,22 @@ class NicePrompt:
             print(f"Press space to choose an option, enter to finish. Selected {a}")
             for c, i in enumerate(options.keys()):
                 if c == selected and c in chosen:
-                    print(f"{_.lightgreen} 🭬 {i}{_.normal}")
+                    filler = " " * (_.width - (len(i) + 5))
+                    print(f"{_.lightgreen} 🭬 {i}{_.normal}{filler}")
                 elif c == selected:
-                    print(f"{_.lightgreen} 🭬 {_.normal}{i}")
+                    filler = " " * (_.width - (len(i) + 5))
+                    print(f"{_.lightgreen} 🭬 {_.normal}{i}{filler}")
                 elif c in chosen:
-                    print(f"{_.lightgreen} • {i}{_.normal}")
+                    filler = " " * (_.width - (len(i) + 5))
+                    print(f"{_.lightgreen} • {i}{_.normal}{filler}")
                 else:
-                    print(f" ◦ {i}")
+                    filler = " " * (_.width - (len(i) + 5))
+                    print(f" ◦ {i}{filler}")
 
             p = _.move_up(len(options) + 1)
 
         print_list()
-        with _.cbreak():
+        with _.cbreak(), _.hidden_cursor():
             while True:
                 val = _.inkey()
                 if val.code == 343 and len(chosen) >= required:
@@ -173,8 +182,8 @@ class NicePrompt:
 
         return [options[list(options.keys())[i]] for i in chosen]
 
-    def number(self, number_type, start=0, end=0):
-        """The suer can enter a number with optional bounds
+    def number(self, number_type, start=None, end=None):
+        """The user can enter a number with optional bounds
 
         Args:
             number_type (class): The class of the number you want the user to enter. e.g. int float
@@ -187,8 +196,13 @@ class NicePrompt:
 
         with _.cbreak():
             fromstr = ""
-            if start != 0 or end != 0:  # if bounds were specified
-                fromstr = f" from {start} to {end}"
+            if start != None or end != None:  # if bounds were specified
+                if start != None and end != None:
+                    fromstr = f" from {start} to {end}"
+                elif start != None:
+                    fromstr = f" starting from {start}"
+                else:
+                    fromstr = f" up to {end}"
             # make a prompt
             prompt = f"Please enter a {_.bright_yellow}{str(number_type.__name__)}{_.normal}{fromstr}."
             print(prompt)
@@ -230,18 +244,24 @@ class NicePrompt:
                         # cast the input to the specified type and return
                         return number_type(num)
                 # if the inputted character is a digit or a dot
-                elif val in list(string.digits + ".") and len(num) < _.width:
+                elif val in list(string.digits + ".-") and len(num) < _.width:
                     # add it at the cursor position
                     num = num[:csr] + val + num[csr:]
                     csr += 1  # move the cursor forward
                 try:
                     i = number_type(num)  # cast the input to the desired type
-                    if start == 0 and end == 0:  # if there are no bounds
+                    if start == None and end == None:  # if there are no bounds
                         valid = True
-                    elif i >= start and i <= end:  # if the number is within bounds
-                        valid = True
-                    else:  # it is not within bounds
-                        valid = False
+                        print("nobounds\n")
+                    else:
+                        if start != None and end != None and i >= start and i <= end:
+                            valid = True
+                        elif start != None and end == None and i >= start:
+                            valid = True
+                        elif end != None and start == None and i <= end:
+                            valid = True
+                        else:
+                            valid = False
                 except:  # the input couldn't be casted
                     valid = False
                 # print the inputted number out and move the terminal cursor to its correct position
@@ -250,3 +270,24 @@ class NicePrompt:
                     end="",
                 )
                 sys.stdout.flush()
+
+    def confirm(self):
+        _ = self.terminal
+
+        with _.cbreak(), _.hidden_cursor():
+            ret = True
+            while True:
+                print(
+                    f"{_.lightgreen if ret else ''}True {_.lightgreen if not ret else _.normal}False{_.normal}{_.move_left(10)}",
+                    end="",
+                )
+                sys.stdout.flush()
+                val = _.inkey()
+                if val.code == 343:  # if enter key pressed
+                    break
+                if val.code == 260 or val.code == 261:
+                    ret = (
+                        not ret
+                    )  # No matter which arrow key you pressed it will still move to the other option, when there are only 2
+        print(f"{_.clear_eol}{_.lightgreen if ret else _.red}{ret}{_.normal}")
+        return ret
